#
# spec file for package python-quantities
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-quantities
Version:        0.16.1
Release:        1.1
Summary:        Package for physical quantities with units
License:        BSD-3-Clause
URL:            https://github.com/python-quantities/python-quantities/
Source:         https://files.pythonhosted.org/packages/source/q/quantities/quantities-%{version}.tar.gz
Patch0:         reproducible.patch
BuildRequires:  %{python_module base >= 3.9}
BuildRequires:  %{python_module numpy >= 1.22}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-numpy >= 1.22
BuildArch:      noarch
%python_subpackages

%description
Support for physical quantities with units, based on numpy.

%prep
%autosetup -p1 -n quantities-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
mv quantities .quantities
%pytest -v --pyargs quantities.tests
mv .quantities quantities

%files %{python_files}
%doc CHANGES.txt README.rst
%license doc/user/license.rst
%{python_sitelib}/quantities
%{python_sitelib}/quantities-%{version}.dist-info

%changelog
* Wed Nov 27 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.16.1:
  * Fixed a couple of small bugs
  * Added umath funcs: `maximum` & `minimum`
  * Added support for NumPy 2.0, while maintaining support for older
    versions back to 1.22
  * Fixed a potential security hole
  * Dropped support for Python 3.8
* Mon Jul 22 2024 Steve Kowalik <steven.kowalik@suse.com>
- Restrict numpy to < 2, not quite supported yet.
* Sun Jan 21 2024 Dirk Müller <dmueller@suse.com>
- update to 0.15.0:
  * Quantities now has type stubs for all classes and functions.
  * Fixed a number of deprecations coming from NumPy
  * Dropped support for NumPy 1.19, added testing for Numpy 1.25
    and 1.26, and for Python 3.12
* Sun Oct 15 2023 Bernhard Wiedemann <bwiedemann@suse.com>
- Add reproducible.patch to drop build date (boo#1047218)
* Wed May 31 2023 Dirk Müller <dmueller@suse.com>
- update to 0.14.1:
  * Fixed a bug when scaling quantities with integer dtype
* Wed Feb  8 2023 Daniel Garcia <daniel.garcia@suse.com>
- Update to 0.14.0
  * Added decimeter to list of supported units PR#202
  * Removed deprecated mb as symbol for millibar unit PR#203
  * Fixed failure to preserve dtype in rescale PR#204
  * Added exp2 as a supported ufunc
  * Fixed failure to handle units with floordiv PR#207
  * Added femtofarad (fF) to list of supported units
  * Dropped support for Python 3.7
  * Dropped support for NumPy versions older than 1.19
  * Converted the project packaging from setup.py-based to pyproject.toml-based
* Thu Jun 23 2022 Arun Persaud <arun@gmx.de>
- specfile:
  * require python >= 3.7 and updated numpy version requirement
- update to version 0.13.0
  * Dropped support for Python versions older than 3.7, in particular,
    for Python 2.7.
  * Dropped support for NumPy versions older than 1.16
  * Switched test runner to pytest, and CI to Github Actions
* Sat Nov 27 2021 Arun Persaud <arun@gmx.de>
- specfile:
  * be more specific in %%files section
- update to version 0.12.5:
  * Added preferred units support for .rescale
  * Added dimensionless unit 'lsb' (least significant bit)
  * Added SI multiples for Kelvin
  * Fixed invalid escape sequence
* Fri Apr 23 2021 Steve Kowalik <steven.kowalik@suse.com>
- Don't build for Python 3.6, due to no NumPy.
* Wed Jan 20 2021 andy great <andythe_great@pm.me>
- Change from pytest to unittest.
- Remove test_umath because the test no longer fails when expected
  to fail.
* Thu Jan 30 2020 Todd R <toddrme2178@gmail.com>
- Update to 0.12.4
  * Fix broken support for `pq.Quanitty('mbar')`
  * Add a `__format__` implementation for Quantity
  * Fix `np.arctan2` regression due to newer numpy version
  * Fix "<ufunc 'clip'> not supported" error
  * Test against Python 3.8 and NumPy 1.17
- Update to 0.12.3
  * Updates to support NumPy up to version 1.16.1, and Python 3.7.
  * Added microcoulomb and millicoulomb units.
- Drop upstream-included no_ufunc_clip.patch
* Wed Dec  4 2019 Todd R <toddrme2178@gmail.com>
- Initial version
- Add no_ufunc_clip.patch
  Fixes: https://github.com/python-quantities/python-quantities/issues/158
  From: https://github.com/python-quantities/python-quantities/pull/165
